Move authData calculation logic to each LISP message builder classs

Change-Id: I61f13cbb77c58f06efce7e9450f11d328749b247
diff --git a/protocols/lisp/msg/src/main/java/org/onosproject/lisp/msg/protocols/LispMapRegister.java b/protocols/lisp/msg/src/main/java/org/onosproject/lisp/msg/protocols/LispMapRegister.java
index f5341c2..797ebd7 100644
--- a/protocols/lisp/msg/src/main/java/org/onosproject/lisp/msg/protocols/LispMapRegister.java
+++ b/protocols/lisp/msg/src/main/java/org/onosproject/lisp/msg/protocols/LispMapRegister.java
@@ -103,7 +103,7 @@
      *
      * @return authentication data
      */
-    byte[] getAuthenticationData();
+    byte[] getAuthData();
 
     /**
      * Obtains a collection of records.
@@ -142,6 +142,14 @@
         RegisterBuilder withNonce(long nonce);
 
         /**
+         * Sets authentication key.
+         *
+         * @param key authentication key
+         * @return RegisterBuilder object
+         */
+        RegisterBuilder withAuthKey(String key);
+
+        /**
          * Sets authentication data length.
          *
          * @param authDataLength authentication data length
@@ -160,10 +168,10 @@
         /**
          * Sets authentication data.
          *
          * @param authenticationData authentication data
          * @return RegisterBuilder object
          */
-        RegisterBuilder withAuthenticationData(byte[] authenticationData);
+        RegisterBuilder withAuthData(byte[] authData);
 
         /**
          * Sets a collection of map records.
@@ -160,10 +168,10 @@
          * Sets authentication data.
          *
-         * @param authenticationData authentication data
+         * @param authData authentication data
          * @return RegisterBuilder object
          */